@@ -31,7 +31,7 @@ setMethod("TSput",   signature(x="ANY", serIDs="character", con="TSPostgreSQLCon
        TSdescription.=TSdescription(x), TSdoc.=TSdoc(x), TSlabel.=TSlabel(x),
        TSsource.=TSsource(x),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-  TSdbi:::TSputSQL(x, serIDs, con, Table=Table, 
+   TSputSQL(x, serIDs, con, Table=Table, 
    TSdescription.=TSdescription., TSdoc.=TSdoc., TSlabel.=TSlabel.,
     TSsource.=TSsource.,
    vintage=vintage, panel=panel) )
@@ -42,7 +42,7 @@ setMethod("TSget",   signature(serIDs="character", con="TSPostgreSQLConnection")
        tf=NULL, start=tfstart(tf), end=tfend(tf), names=NULL, 
        TSdescription=FALSE, TSdoc=FALSE, TSlabel=FALSE, TSsource=TRUE,
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-   TSdbi:::TSgetSQL(serIDs, con, TSrepresentation=TSrepresentation,
+     TSgetSQL(serIDs, con, TSrepresentation=TSrepresentation,
        tf=tf, start=start, end=end, names=names, 
        TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
          TSsource=TSsource,
@@ -51,29 +51,29 @@ setMethod("TSget",   signature(serIDs="character", con="TSPostgreSQLConnection")
 setMethod("TSdates",    signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-      TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel) )
+      TSdatesSQL(serIDs, con, vintage=vintage, panel=panel) )
 
 
 setMethod("TSdescription",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdescriptionSQL(x=x, con=con) )
+        TSdescriptionSQL(x=x, con=con) )
 
 setMethod("TSdoc",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdocSQL(x=x, con=con) )
+        TSdocSQL(x=x, con=con) )
 
 setMethod("TSlabel",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSlabelSQL(x=x, con=con) )
+        TSlabelSQL(x=x, con=con) )
 
 setMethod("TSsource",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSsourceSQL(x=x, con=con) )
+        TSsourceSQL(x=x, con=con) )
 
 setMethod("TSdelete", signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
    vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-       TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
+       TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
 
 setMethod("TSvintages", 
    signature(con="TSPostgreSQLConnection"),
